table {
  border-bottom: 1px solid $bg-primary;
  background-color: #fff;
  width: 100%;

  th,
  td {
    padding: 10px;
    vertical-align: top;
    &:first-of-type:not(:only-child) {
      padding-left: $padding-width;
    }

    &:last-of-type:not(:only-child) {
      padding-right: $padding-width;
    }

    &.checkbox{
      width: 70px;
      padding: 10px !important;
      text-align: center;
    }
  }

  caption {
    background-color: #fff;
    text-align: left;
    text-transform: capitalize;
    font-size: 32px;
  }

  thead {
    border-bottom: 1px solid $bg-primary;
  }

  th {
    text-transform: uppercase;
    text-align: left;

    a {
      color: $black;
    }

    &.sortable {

      .fa {
        margin-left: 10px;
      }
    }
  }

  tbody[draggable=true] {    
    tr:hover td{
      background-color: $bg-primary;
    }
  }

  tbody {
    tr {
      &:hover {
        background-color: $bg-primary;
      }
    }
  }

  &.is-empty {

    &,
    thead {
      border: none;
    }
  }
}
